@@ -139,11 +139,30 @@ class Bible:
     def translation(self, translation: Translation):
         self._translation = translation
 
+    def _extract_verses(self, chapter_text: str) -> list[str]:
+        verses: list = []
+        i = 1
+        j = 2
+        pos_i = chapter_text.find(str(i))
+        pos_j = chapter_text.find(str(j))
+        while chapter_text.find(str(j)) != -1:
+            verses.append(chapter_text[pos_i+len(str(i)):pos_j].strip())
+            i += 1
+            j += 1
+            pos_i = chapter_text.find(str(i))
+            pos_j = chapter_text.find(str(j))
+        verses.append(chapter_text[pos_i+len(str(i)):].strip())
+        return verses
+
     def scrape_book(self, book: _Book) -> tuple[str, list[list[str]]]:
         def _clean_verses(chapter_text: str) -> str:
             cleaned_verses: list = []
             chapter_text_cleaned = chapter_text.replace("\n", "")
-            verses = re.split(r"\d+", chapter_text_cleaned)
+            chapter_text_cleaned = chapter_text_cleaned.replace("(-)", "-")
+            chapter_text_cleaned = chapter_text_cleaned.replace("*", "")
+            chapter_text_cleaned = re.sub(r"  +", " ", chapter_text_cleaned)
+            chapter_text_cleaned = chapter_text_cleaned.replace("  ", " ")
+            verses = self._extract_verses(chapter_text_cleaned)
             for verse in verses:
                 clean_verse = verse.strip()
                 if clean_verse in f"{string.whitespace}{string.punctuation}":
@@ -157,10 +176,10 @@ class Bible:
                 f"{self._base_url}{self._translation.code}/{book.name}.{i+1}"
             )
             soup = BeautifulSoup(request.text, "html.parser")
-            for element in soup.findAll("span", "note"):
+            for element in soup.find_all("span", "note"):
                 element.decompose()
             chapter_text: str = ""
-            for element in soup.findAll("div", "p"):
+            for element in soup.find_all(name="div", attrs={"p", "q1", "q2", "m", "nb"}):
                 chapter_text = f"{chapter_text}{element.get_text()}"
             chapters.append(_clean_verses(chapter_text))
         return chapters
@@ -187,13 +206,12 @@ class Bible:
 
     def save_to_logos(self) -> None:
         def _line_prefix(
-            language: str,
-            translation_n: str,
             book_name: str,
             chapter_num: int,
             verse_num: int,
+            logos_translation: str = "NO2011",
         ) -> str:
-            return f"[[@Bible{language}{translation_n}:{book_name} {chapter_num}:{verse_num}]]  {verse_num} "
+            return f"[[@Bible{logos_translation}:{book_name} {chapter_num}:{verse_num}]]  {verse_num} "
 
         def _line_suffix(verse: str) -> str:
             return f"{{{{field-on:bible}}}}{verse}{{{{field-off:bible}}}}\n"
@@ -201,7 +219,7 @@ class Bible:
         def _chapter_separator(num: int, language: str = "NO"):
             title: str = "KAPITTEL"
             if language == "NO":
-                return f"\n{title} 1{{{{field-on:bible}}}}{{{{field-off:bible}}}}\n"
+                return f"\n{title} {num}{{{{field-on:bible}}}}{{{{field-off:bible}}}}\n"
             else:
                 raise RuntimeError(f"Language {language} not supported")
 
@@ -214,7 +232,7 @@ class Bible:
                     lines.append(f"{_chapter_separator(i)}")
                     for j, verse in enumerate(chapter, start=1):
                         lines.append(
-                            f"{_line_prefix(self.translation.language, self.translation.code, book.logos_name, i, j)}"
+                            f"{_line_prefix(book.logos_name, i, j)}"
                             f"{_line_suffix(verse)}"
                         )
             bible_file.writelines(lines)
